#!/bin/bash
#
# Guralp Configuration System
#   Copyright (c) 2008-2010 Guralp Systems Ltd. All rights reserved.
#
#   GSTM client config

# Handle the navbar query without loading anything
if [ "X$1" == "X--navbar" ]
then
	echo "servicestop	Services"
	echo "servicessub/gstm-client	gstm-client"
	echo "gstm-client/$3	$3"
	exit 0
fi

# Load support functions
script_dir=$(dirname $0)
. $script_dir/functions.sh
. $script_dir/svc_funcs.sh


do_read() {
	# Standard control info
	gcs_svc_read || return 1

	# Now the service type dependant variables

	gcs_var "d_connect_host"	""
	gcs_var "d_connect_service"	"gstm"
	gcs_var "d_connect_username"	"$(hostname)"
	gcs_var "d_connect_key"		""
	gcs_var "d_connect_error_exit_delay"	"30"
	gcs_var "d_watchdog_interval"	"30"
	gcs_var "d_failover_services"	""
	gcs_var "d_link_up_cmd"		""

	if [ -r "$CFGFILE" ]
	then
	    gcs_var_o "connect_host"
	    gcs_var_o "connect_service"
	    gcs_var_o "connect_username"
	    gcs_var_o "connect_key"
	    gcs_var_o "connect_error_exit_delay"
	    gcs_var_o "watchdog_interval"
	    gcs_var_o "failover_services"
	    gcs_var_o "link_up_cmd"
	fi
}


do_check() {

	gcs_read_vars

	# Standard service control/info vars
	gcs_svc_check

	# Service dependant variables
	# Checks are done by the main engine so nothing to do here
}


do_write() {
	local -i i
	local val

	do_check
	if (( gcs_errors > 0 ))
	then
	    return
	fi

	if gcs_truefalse "${new_delete:-false}"
	then
		gcs_svc_delete "$name" "$sel"
	fi

	gcs_ensure_cfgfile_exists $CFGFILE

	# Standard path controls
	gcs_set_varf DESC	$CTLFILE "$desc"

	# Do the simple keywords in place
	gcs_set_varcf "connect_host"		"${CFGFILE}"	"${new_connect_host}"
	gcs_set_varcf "connect_service"		"${CFGFILE}"	"${new_connect_service}"
	gcs_set_varcf "connect_username"	"${CFGFILE}"	"${new_connect_username}"
	gcs_set_varcf "connect_key"		"${CFGFILE}"	"${new_connect_key}"
	gcs_set_varcf "connect_error_exit_delay"	"${CFGFILE}"	"${new_connect_error_exit_delay}"
	gcs_set_varcf "watchdog_interval"	"${CFGFILE}"	"${new_watchdog_interval}"
	gcs_set_varcf "failover_services"	"${CFGFILE}"	"${new_failover_services}"
	gcs_set_varcf "link_up_cmd"		"${CFGFILE}"	"${new_link_up_cmd}"

	# Update the service script
	gcs_update_svc "$name" "$sel" "$enable" "$desc" "$CFGFILE" "$CTLFILE" \
			"$SRVBASE"
	
	gcs_svc_reload "$name" "$sel"
}


name="$2"
sel="$3"

CFGFILE="$CONFIGDIR/$name/${sel}.local"
CTLFILE="$CONFIGDIR/$name/${sel}.ctl.local"
SRVBASE="$SERVDIR/$name"


case "X$1" in
X--check)	do_check	;;
X--write)	do_write	;;
X--read)	do_read		;;
*)		exit 1		;;
esac

gcs_cleanup
exit 0
